@@ -17,7 +17,7 @@
  */
 
 /*
- * Japanese support by TAKIZAWA Takashi.
+ * Japanese support by TAKIZAWA Takashi <taki@luna.email.ne.jp>.
  */
 
 #include "mutt.h"
@@ -332,12 +332,13 @@ int iswalnum (wint_t wc)
  */
 int wcwidth_ja (wchar_t ucs)
 {
-  if (ucs >= 2e80)
+  if (ucs >= 0x3021)
     return -1; /* continue with the normal check */
   /* a rough range for quick check */
   if ((ucs >= 0x00a1 && ucs <= 0x00fe) || /* Latin-1 Supplement */
       (ucs >= 0x0391 && ucs <= 0x0451) || /* Greek and Cyrillic */
-      (ucs >= 0x2010 && ucs <= 0x266f))   /* Symbols */
+      (ucs >= 0x2010 && ucs <= 0x266f) || /* Symbols */
+      (ucs >= 0x3000 && ucs <= 0x3020))   /* CJK Symbols and Punctuation */
     return 2;
   else
     return -1;
