@@ -155,7 +155,8 @@ typedef enum
 #define M_TREE_STAR		8
 #define M_TREE_HIDDEN		9
 #define M_TREE_MISSING		10
-#define M_TREE_MAX		11
+#define M_TREE_EQUALS		11
+#define M_TREE_MAX		12
 
 #define M_THREAD_COLLAPSE	(1<<0)
 #define M_THREAD_UNCOLLAPSE	(1<<1)
@@ -300,6 +301,7 @@ enum
 enum
 {
   OPTALLOW8BIT,
+  OPTALLOWANSI,
   OPTARROWCURSOR,
   OPTASCIICHARS,
   OPTASKBCC,
@@ -316,6 +318,7 @@ enum
   OPTCONFIRMCREATE,
   OPTDELETEUNTAG,
   OPTDIGESTCOLLAPSE,
+  OPTDUPTHREADS,
   OPTEDITHDRS,
   OPTENCODEFROM,
   OPTENVFROM,
@@ -435,6 +438,7 @@ enum
   OPTSIGNALSBLOCKED,	/* (pseudo) using by mutt_block_signals () */
   OPTSYSSIGNALSBLOCKED,	/* (pseudo) using by mutt_block_signals_system () */
   OPTNEEDRESORT,	/* (pseudo) used to force a re-sort */
+  OPTRESORTINIT,	/* (pseudo) used to force the next resort to be from scratch */
   OPTVIEWATTACH,	/* (pseudo) signals that we are viewing attachments */
   OPTFORCEREDRAWINDEX,	/* (pseudo) used to force a redraw in the main index */
   OPTFORCEREDRAWPAGER,	/* (pseudo) used to force a redraw in the pager */
@@ -619,6 +623,7 @@ typedef struct header
   unsigned int superseded : 1; /* got superseded? */
   unsigned int replied : 1;
   unsigned int subject_changed : 1; /* used for threading */
+  unsigned int threaded : 1;	    /* used for threading */
   unsigned int display_subject : 1; /* used for threading */
   unsigned int recip_valid : 1;  /* is_recipient is valid */
   unsigned int active : 1;	    /* message is not to be removed */
@@ -672,6 +677,9 @@ typedef struct header
 typedef struct thread
 {
   unsigned int fake_thread : 1;
+  unsigned int duplicate_thread : 1;
+  unsigned int sort_children : 1;
+  unsigned int check_subject : 1;
   struct thread *parent;
   struct thread *child;
   struct thread *next;
@@ -792,7 +800,9 @@ typedef struct
 #define state_puts(x,y) fputs(x,(y)->fpout)
 #define state_putc(x,y) fputc(x,(y)->fpout)
 
-void state_prefix_putc(char, STATE *);
+void state_mark_attach (STATE *);
+void state_attach_puts (const char *, STATE *);
+void state_prefix_putc (char, STATE *);
 int  state_printf(STATE *, const char *, ...);
 
 #include "ascii.h"
